#[repr(transparent)]pub struct UsbOtg1Ctrl(pub u32);Expand description
USB OTG1 Control Register
Tuple Fields
0: u32Implementations
Sourceimpl UsbOtg1Ctrl
impl UsbOtg1Ctrl
Sourcepub const fn over_cur_dis(&self) -> OverCurDis
pub const fn over_cur_dis(&self) -> OverCurDis
Disable OTG1 Overcurrent Detection
Sourcepub const fn set_over_cur_dis(&mut self, val: OverCurDis)
pub const fn set_over_cur_dis(&mut self, val: OverCurDis)
Disable OTG1 Overcurrent Detection
Sourcepub const fn over_cur_pol(&self) -> OverCurPol
pub const fn over_cur_pol(&self) -> OverCurPol
OTG1 Polarity of Overcurrent The polarity of OTG1 port overcurrent event
Sourcepub const fn set_over_cur_pol(&mut self, val: OverCurPol)
pub const fn set_over_cur_pol(&mut self, val: OverCurPol)
OTG1 Polarity of Overcurrent The polarity of OTG1 port overcurrent event
Sourcepub const fn pwr_pol(&self) -> PwrPol
pub const fn pwr_pol(&self) -> PwrPol
OTG1 Power Polarity This bit should be set according to PMIC Power Pin polarity.
Sourcepub const fn set_pwr_pol(&mut self, val: PwrPol)
pub const fn set_pwr_pol(&mut self, val: PwrPol)
OTG1 Power Polarity This bit should be set according to PMIC Power Pin polarity.
Sourcepub const fn wie(&self) -> Wie
pub const fn wie(&self) -> Wie
OTG1 Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up interrupt
Sourcepub const fn set_wie(&mut self, val: Wie)
pub const fn set_wie(&mut self, val: Wie)
OTG1 Wake-up Interrupt Enable This bit enables or disables the OTG1 wake-up interrupt
Sourcepub const fn wkup_sw_en(&self) -> WkupSwEn
pub const fn wkup_sw_en(&self) -> WkupSwEn
OTG1 Software Wake-up Enable
Sourcepub const fn set_wkup_sw_en(&mut self, val: WkupSwEn)
pub const fn set_wkup_sw_en(&mut self, val: WkupSwEn)
OTG1 Software Wake-up Enable
Sourcepub const fn set_wkup_sw(&mut self, val: WkupSw)
pub const fn set_wkup_sw(&mut self, val: WkupSw)
OTG1 Software Wake-up
Sourcepub const fn wkup_id_en(&self) -> WkupIdEn
pub const fn wkup_id_en(&self) -> WkupIdEn
OTG1 Wake-up on ID change enable
Sourcepub const fn set_wkup_id_en(&mut self, val: WkupIdEn)
pub const fn set_wkup_id_en(&mut self, val: WkupIdEn)
OTG1 Wake-up on ID change enable
Sourcepub const fn wkup_vbus_en(&self) -> WkupVbusEn
pub const fn wkup_vbus_en(&self) -> WkupVbusEn
OTG1 wake-up on VBUS change enable
Sourcepub const fn set_wkup_vbus_en(&mut self, val: WkupVbusEn)
pub const fn set_wkup_vbus_en(&mut self, val: WkupVbusEn)
OTG1 wake-up on VBUS change enable
Sourcepub const fn wkup_dpdm_en(&self) -> WkupDpdmEn
pub const fn wkup_dpdm_en(&self) -> WkupDpdmEn
Wake-up on DPDM change enable
Sourcepub const fn set_wkup_dpdm_en(&mut self, val: WkupDpdmEn)
pub const fn set_wkup_dpdm_en(&mut self, val: WkupDpdmEn)
Wake-up on DPDM change enable